package ch.std.meteo.test.repositories;

import static org.junit.jupiter.api.Assertions.assertArrayEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

import java.util.List;

import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.junit.jupiter.api.extension.ExtendWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.orm.jpa.DataJpaTest;
import org.springframework.context.annotation.ComponentScan;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit.jupiter.SpringExtension;

import ch.std.meteo.jpa.MeteoData;
import ch.std.meteo.repositories.MeteoDataRepository;
import ch.std.meteo.test.setup.MeteoDataTestSetup;

@ExtendWith(SpringExtension.class)
@DataJpaTest
@ComponentScan(basePackages = {"ch.std.meteo.test"})
@ActiveProfiles("unittest")
public class MeteoDataRepositoryJPATest {

	@Autowired
	private MeteoDataRepository meteoDataRepository;
	@Autowired
	private MeteoDataTestSetup meteoDataTestSetup;

	@BeforeEach
	public void setup() {
		this.meteoDataTestSetup.setup();
	}

	@AfterEach
	public void teardown() {
		this.meteoDataTestSetup.teardown();
	}

	@Test
	public void testMeteoDataFindAll() {
		List<MeteoData> meteoDataList = this.meteoDataRepository.findAll();
		assertNotNull(meteoDataList);
		Double[] loadedTemperatures = meteoDataList.stream().map(md -> md.getTemperature()).toArray(Double[]::new);
		assertArrayEquals(MeteoDataTestSetup.TEMPERATURES, loadedTemperatures);		
	}

}
